import type { ILogger } from '@visactor/vutils';
import type { ISemanticMark, ISemanticMarkSpec, ParsedSimpleEncode, WithDefaultEncode, SemanticTooltipOption, SemanticAxisOption, SemanticPlayerOption, SemanticLabelOption, SemanticDataZoomOption, SemanticSliderOption, SemanticLegendOption, SemanticCrosshairOption, CoordinateOption, AxisSpec, CrosshairSpec, DatazoomSpec, LabelSpec, LegendSpec, PlayerSpec, SliderSpec, CoordinateSpec, DataSpec, ChannelEncodeType, ScaleSpec, TransformSpec, MarkAnimationSpec, ViewSpec, MarkType, Nil, ValueOf, GenerateBaseEncodeSpec, IAnimationConfig, MarkSpec, MarkRelativeItemSpec, IPlot, SemanticGridOption, GridSpec, TitleSpec, SemanticTitleOption, InteractionSpec } from '@visactor/vgrammar-core';
import type { ITextAttribute } from '@visactor/vrender-core';
export declare abstract class SemanticMark<EncodeSpec, K extends string> implements ISemanticMark<EncodeSpec, K> {
    spec: ISemanticMarkSpec<EncodeSpec, K>;
    viewSpec?: ViewSpec;
    readonly uid: number;
    protected _logger: ILogger;
    protected _coordinate: CoordinateOption;
    readonly type: string;
    readonly plot: IPlot;
    constructor(type: string, id?: string | number, plot?: IPlot);
    parseSpec(spec: Partial<ISemanticMarkSpec<EncodeSpec, K>>): this;
    coordinate(option: CoordinateOption): this;
    data(values: any, transform?: TransformSpec[], id?: string): this;
    encode(channel: K, option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): this;
    scale(channel: string, option: Partial<ScaleSpec>): this;
    style(style: Partial<EncodeSpec & any>): this;
    transform(option: TransformSpec | TransformSpec[]): this;
    state(state: string, option: Partial<EncodeSpec>): this;
    animate(state: string, option: IAnimationConfig | IAnimationConfig[]): this;
    axis(channel: string, option?: SemanticAxisOption | boolean, layout?: MarkRelativeItemSpec): this;
    grid(channel: string, option?: SemanticGridOption | boolean): this;
    legend(channel: string, option?: SemanticLegendOption | boolean, layout?: MarkRelativeItemSpec): this;
    crosshair(channel: string, option?: SemanticCrosshairOption | boolean): this;
    tooltip(option: SemanticTooltipOption | boolean): this;
    slider(channel: string, option?: SemanticSliderOption | boolean, layout?: MarkRelativeItemSpec): this;
    datazoom(channel: string, option?: SemanticDataZoomOption | boolean, layout?: MarkRelativeItemSpec): this;
    label(channel: string, option?: SemanticLabelOption | boolean): this;
    player(data?: any[], option?: SemanticPlayerOption | boolean, layout?: MarkRelativeItemSpec): this;
    title(option: SemanticTitleOption, layout?: MarkRelativeItemSpec): this;
    protected getPalette(): import("@visactor/vrender-core").IColor[];
    abstract setMarkType(): MarkType;
    abstract parseScaleByEncode(channel: K, option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    abstract convertMarkEncode(encode: WithDefaultEncode<EncodeSpec, K>): GenerateBaseEncodeSpec<EncodeSpec>;
    protected setDefaultDataTransform(): TransformSpec[];
    protected setMultipleData(): DataSpec[];
    protected setDefaultMarkTransform(): TransformSpec[];
    protected convertMarkTransform(userTransform: TransformSpec[], defaultTransform?: TransformSpec[]): any[];
    protected convertMarkAnimation(): MarkAnimationSpec;
    protected convertSimpleMarkEncode(encode: WithDefaultEncode<EncodeSpec, K>): ParsedSimpleEncode<EncodeSpec, K>;
    protected getDataIdOfFiltered(): string;
    protected getDataIdOfMain(): string;
    protected getDataIdOfPlayer(): string;
    protected getDataZoomScaleId(channel: string): {
        x: string;
        y: string;
    };
    protected getScaleId(channel: string): any;
    protected getMarkId(): string;
    protected getComponentId(id: string, component?: string): string;
    protected getScaleSpec(scaleId: string): ScaleSpec;
    protected parseScaleOfEncodeX(option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected parseScaleOfEncodeY(option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected parseScaleOfEncodeColor(option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected parseScaleOfEncodeStroke(option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected parseScaleOfEncodeGroup(option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected parseScaleOfCommonEncode(channel: K, option: ValueOf<WithDefaultEncode<EncodeSpec, K>, K>): ScaleSpec | Nil;
    protected setDefaultAxis(): Record<string, Partial<AxisSpec>>;
    protected parseAxisSpec(): {
        marks: AxisSpec[];
        interactions: InteractionSpec[];
    };
    protected parseGridSpec(): {
        marks: GridSpec[];
        interactions: InteractionSpec[];
    };
    protected parseOption<T>(spec: {
        option: T | boolean;
        layout?: MarkRelativeItemSpec;
    } | T | boolean): {
        option: boolean | T;
        layout: MarkRelativeItemSpec;
    };
    protected setDefaultLegend(): Record<string, Partial<LegendSpec>>;
    protected parseLegendSpec(): {
        marks: LegendSpec[];
        interactions: InteractionSpec[];
    };
    protected setDefaultCrosshair(): Record<string, Pick<CrosshairSpec, 'crosshairShape' | 'crosshairType'>>;
    protected getVisualChannel(channel: 'x' | 'y'): 'x' | 'y' | 'angle' | 'radius';
    protected parseCrosshairSpec(): {
        marks: MarkSpec[];
        interactions: CrosshairSpec[];
    };
    protected setDefaultTooltip(): SemanticTooltipOption | Nil;
    protected parseTooltipSpec(): {
        marks: MarkSpec[];
        interactions: InteractionSpec[];
    };
    protected setDefaultSlider(): Record<string, Partial<SliderSpec>>;
    protected parseSliderSpec(): {
        marks: SliderSpec[];
        interactions: InteractionSpec[];
    };
    protected setDefaultDataZoom(): Record<string, Partial<DatazoomSpec>>;
    protected getVisiualPositionByDimension(channel: string): "left" | "bottom";
    protected parseDatazoomSpec(): {
        marks: DatazoomSpec[];
        interactions: InteractionSpec[];
    };
    protected setDefaultLabel(): Record<string, Partial<LabelSpec>>;
    protected getLabelPosition(): string;
    protected setLabelTextGetter(channel: string, option: SemanticLabelOption | boolean): ChannelEncodeType<ITextAttribute['text']>;
    protected parseLabelSpec(): {
        marks: LabelSpec[];
        interactions: InteractionSpec[];
    };
    protected setDefaultPlayer(): Record<string, Partial<PlayerSpec>>;
    protected parsePlayerSpec(): {
        marks: PlayerSpec[];
        interactions: InteractionSpec[];
    };
    protected parseTitleSpec(): {
        marks: TitleSpec[];
        interactions: InteractionSpec[];
    };
    protected parseDataSpec(): DataSpec[];
    protected parseScaleSpec(): (ScaleSpec & {
        userScale?: ScaleSpec;
    })[];
    protected parseCoordinateSpec(): CoordinateSpec[];
    protected setMainMarkEnterEncode(): Partial<any>;
    protected setMainMarkSpec(parsedMainSpec: any): {};
    protected setMultiMarksSpec(): MarkSpec[];
    toViewSpec(): ViewSpec;
    clear(): void;
}
